@@ -18,7 +18,8 @@ class TokenType(Enum):
     TAB = auto()
     LOWER_INDEFINITE_ARTICLE = auto()
     UPPER_INDEFINITE_ARTICLE = auto()
-    BACKSLASH = auto()
+    DOUBLE_BACKSLASH = auto()
+    SINGLE_BACKSLASH = auto()
     FORWARD_SLASH = auto()
     REGEX = auto()
     DIGIT = auto()
