@@ -7,7 +7,8 @@ from twaddle.interpreter.synchronizer import (
 
 
 def test_synchronizer_manager():
-    locked = SynchronizerManager.create_synchronizer("x", "locked", 1)
+    sync_manager = SynchronizerManager()
+    locked = sync_manager.create_synchronizer("x", "locked", 1)
     assert isinstance(locked, LockedSynchronizer)
 
 
